@@ -235,7 +235,11 @@ boundedOpt1d <- function(mnvec,other,bounds) {
 		stop("Parameter 'bounds' must be of class 'boundobj1d'.")
 	}
 
-	if (mnvec[2]==0) { return(c(basicbounds[1],1,0)) }
+	if (mnvec[2]==0) {
+		if (is.finite(basicbounds[[1]])) { return(c(basicbounds[1],1,0)) }
+		else if (is.finite(basicbounds[[2]])) { return(c(basicbounds[2],-1,0)) }
+		else { return(c(other,0,0)) }
+	}
 	E <- (1-mnvec[1]/mnvec[2])*other+mnvec[4]/mnvec[2]
 	if (E<basicbounds[1]) {
 		return(c(basicbounds[1],1,2*(-mnvec[4]+basicbounds[1]*mnvec[2]+other*(mnvec[1]-mnvec[2]))))
